@@ -1,22 +1,22 @@
-import mwutils
-from mwutils.logs import Logger, mili_time
-from mwutils.sys_stat import SystemStats
-
-import os
-import requests
-import warnings
-import jwt
-import time
-import traceback
-import signal
-import json
-import boto3
-import botocore
-import logging
-import numpy as np
-from os import path, getpid
-from random import randrange
 from botocore.exceptions import ClientError
+from random import randrange
+from os import path, getpid
+import numpy as np
+import logging
+import botocore
+import boto3
+import json
+import signal
+import traceback
+import time
+import jwt
+import warnings
+import requests
+import os
+from mwutils.sys_stat import SystemStats
+from mwutils.logs import Logger, mili_time
+import mwutils
+% % writefile / opt/conda/lib/python3.6/site-packages/mwutils/run.py
 
 
 _STEP = 'step'
@@ -154,13 +154,15 @@ class Run():
         else:
             self.org_id = org_id
 
-        self.user_token = user_token
-        # if config_token:
-        #     self.user_token = config_token
-        # elif env_token:
-        #     self.user_token = config_token
-        # else:
-        #     self.user_token = user_token
+        # self.user_token = user_token
+        if config_token:
+            print('config_token')
+            self.user_token = config_token
+        elif env_token:
+            print('env_token')
+            self.user_token = config_token
+        else:
+            self.user_token = user_token
 
         if remote_path:
             self.remote_path = remote_path
@@ -361,6 +363,9 @@ class Run():
                 print(clogger.name, clogger.memoize)
 
         if save_model == True:
+            if self.user_token == '':
+                print('token not specified, please check')
+                return
             class_type = str(type(target))
             epoch_time = int(time.time())
             os.mkdir(str(epoch_time))
@@ -417,7 +422,7 @@ class Run():
                                      )
 
             upload_dir = _path
-            print(upload_dir)
+            prefixes = []
             for subdir, dirs, files in os.walk(upload_dir):
                 for file in files:
                     fullpath = os.path.join(subdir, file)
@@ -427,14 +432,17 @@ class Run():
                         print('uploading file: ', fullpath)
                         response = s3_client.upload_file(
                             fullpath, bucket, object_name)
+                        prefixes.append(object_name)
                     except ClientError as e:
                         logging.error(e)
                         print('Error uploading file ', file)
-
         if self.remote_path:
             tp = int(time.time())
-            json_struct = {"metadata": self.metadata, "best": [
-                {"phase": name, "val": logger.memoize, _TIMESTAMP: tp} for name, logger in self._loggers.items()]}
+            json_struct = {
+                "metadata": self.metadata,
+                "files": prefixes,
+                "best": [{"phase": name, "val": logger.memoize, _TIMESTAMP: tp} for name, logger in self._loggers.items()],
+            }
             for _ in range(3):
                 r = requests.post(self.conclude_remote_path, json=json_struct, headers={"Authorization": jwt.encode(
                     {"whatever": "1"}, "857851b2-c28c-4d94-83c8-f607b50ccd03")})
@@ -445,7 +453,7 @@ class Run():
                         jb = r.json()
                     except:
                         pass
-                    print("resp:", r)
+                    print("Experiment recorded.")
                     msg = "code: {}, resp.json: {}, resp.text: {}".format(
                         r.status_code, jb, r.text)
                     print(msg)
